==> ucloud-ko-fileupload-3.0.5.tgz: package/src/coop-fileupload/fileintable.js <==
import ko from "knockout";
import _ from "lodashmix";
import getLang from '../u-fileupload/i18n'
import { initVM, queryFile, clearFile, initTempId } from './function';
import './fileintable.less'
let tempBuyerTenant = null;
function getXtDomainUrl (buyerTenant) {
  if(tempBuyerTenant == buyerTenant){
    return;
  }
  $.ajax({
    type: 'GET',
    async: false,
    url: `/yonbip-cpu-portal/tenant/dcWorkbenchUrl/${buyerTenant}`,
    success: function (result) {
      let {data, code} = result
      if(code == '200')
      window.sessionStorage.setItem('XtDomainUrl', data + 'iuap-apcom-file')
    }
  });
}
function entry(params) {
  window.creatCoopUrl()
  this.isCooper = true
  const config = {
    inTable: true
  };
  if (!params) {
    params = {};
  }
  if (!params.coopParams) {
    params.coopParams = {
      fileType: 2
    };
  }
  initVM.call(this, params, config);
  this.tempId = params.tempId || ko.observable(initTempId())
  if(params.enableBuyerTenant){
    // console.log('%c 🍸 params: ', 'font-size:20px;background-color: #2EAFB0;color:#fff;', params);
    // 判断url是否有ycCrossTenantBuyerTenant
    let urlTenantBuyerTenant = function () {
      return new Promise((reslove, reject)=>{
          if(new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')){
              getXtDomainUrl (new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant'))
              params.cloneYcCrossTenantBuyerTenant = new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')
              reslove(true)
          }else{
            reslove(true)
          }
      })
    } 
    let crossTenantBuyerTenant =  function () {
      return new Promise((reslove, reject)=>{
        if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant()){
          getXtDomainUrl (params.ycCrossTenantBuyerTenant())
          params.cloneYcCrossTenantBuyerTenant = params.ycCrossTenantBuyerTenant()
          reslove(true)
        }else if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant.subscribe ){
          params.ycCrossTenantBuyerTenant.subscribe(function (value) {
            // console.log('%c 🍉 value: ', 'font-size:20px;background-color: #4b4b4b;color:#fff;', value);
            getXtDomainUrl (value)
            params.cloneYcCrossTenantBuyerTenant = value
            reslove(true)
          })
        }else{
          reslove(true)
        }
      })
    }
    Promise.all([urlTenantBuyerTenant(), crossTenantBuyerTenant()]).then(result => {
      let res = result.every(item => {return item == true})
      if(!res){
        window.sessionStorage.removeItem('XtDomainUrl')
      } 
      initFile(this, params, config)
    })
  }else{
    window.sessionStorage.removeItem('XtDomainUrl')
    initFile(this, params, config)
  }


  //  else {
  //   clearFile(this, params, config);
  // }
}
function initFile (that, params, config) {
  
  let id = config[config.type]();
  if (id && id != '' && id != 0) {
    queryFile(that, params, config);
  }
}
var init = {
  createViewModel: function (params, componentInfo) {
    params.$el = componentInfo.element;
    params.$templateNodes = componentInfo.templateNodes;
    return new entry(params);
  },
};
export const entryCooperTable = entry
export default init;

==> ucloud-ko-fileupload-4.0.5.tgz: package/src/coop-fileupload/fileintable.js <==
import ko from "knockout";
import _ from "lodashmix";
import getLang from '../u-fileupload/i18n'
import { initVM, queryFile, clearFile, initTempId,processingUrl} from './function';
import './fileintable.less'
let tempBuyerTenant = null;
function getXtDomainUrl (buyerTenant) {
  if(tempBuyerTenant == buyerTenant){
    return;
  }
  $.ajax({
    type: 'GET',
    async: false,
    url: `/yonbip-cpu-portal/tenant/dcWorkbenchUrl/${buyerTenant}`,
    success: function (result) {
      let {data, code} = result
      if(code == '200')
      if(data.endsWith('/')){
        data = data.slice(0, -1)
      }
      data = processingUrl(window.location.origin,data)
      window.sessionStorage.setItem('XtDomainUrl', data + '/iuap-apcom-file')
    }
  });
}
function entry(params) {
  window.creatCoopUrl()
  this.isCooper = true
  const config = {
    inTable: true
  };
  if (!params) {
    params = {};
  }
  if (!params.coopParams) {
    params.coopParams = {
      fileType: 7
    };
  }
  initVM.call(this, params, config);
  this.tempId = params.tempId || ko.observable(initTempId())
  if(params.enableBuyerTenant){
    // console.log('%c 🍸 params: ', 'font-size:20px;background-color: #2EAFB0;color:#fff;', params);
    // 判断url是否有ycCrossTenantBuyerTenant
    let urlTenantBuyerTenant = function () {
      return new Promise((reslove, reject)=>{
          if(new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')){
              getXtDomainUrl (new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant'))
              params.cloneYcCrossTenantBuyerTenant = new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')
              reslove(true)
          }else{
            reslove(true)
          }
      })
    } 
    let crossTenantBuyerTenant =  function () {
      return new Promise((reslove, reject)=>{
        if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant()){
          getXtDomainUrl (params.ycCrossTenantBuyerTenant())
          params.cloneYcCrossTenantBuyerTenant = params.ycCrossTenantBuyerTenant()
          reslove(true)
        }else if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant.subscribe ){
          params.ycCrossTenantBuyerTenant.subscribe(function (value) {
            // console.log('%c 🍉 value: ', 'font-size:20px;background-color: #4b4b4b;color:#fff;', value);
            getXtDomainUrl (value)
            params.cloneYcCrossTenantBuyerTenant = value
            reslove(true)
          })
        }else{
          reslove(true)
        }
      })
    }
    Promise.all([urlTenantBuyerTenant(), crossTenantBuyerTenant()]).then(result => {
      let res = result.every(item => {return item == true})
      if(!res){
        window.sessionStorage.removeItem('XtDomainUrl')
      } 
      initFile(this, params, config)
    })
  }else{
    window.sessionStorage.removeItem('XtDomainUrl')
    initFile(this, params, config)
  }


  //  else {
  //   clearFile(this, params, config);
  // }
}
function initFile (that, params, config) {
  
  let id = config[config.type]();
  if (id && id != '' && id != 0) {
    queryFile(that, params, config);
  }
}
var init = {
  createViewModel: function (params, componentInfo) {
    params.$el = componentInfo.element;
    params.$templateNodes = componentInfo.templateNodes;
    return new entry(params);
  },
};
export const entryCooperTable = entry
export default init;
